Class: Aws::Tnb::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Tnb::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-tnb/client.rb,
sig/client.rbs
Overview
An API client for Tnb. To construct a client, you need to configure a :region and :credentials.
client = Aws::Tnb::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateSolFunctionPackageResponseSuccess, _CreateSolNetworkInstanceResponseSuccess, _CreateSolNetworkPackageResponseSuccess, _GetSolFunctionInstanceResponseSuccess, _GetSolFunctionPackageContentResponseSuccess, _GetSolFunctionPackageDescriptorResponseSuccess, _GetSolFunctionPackageResponseSuccess, _GetSolNetworkInstanceResponseSuccess, _GetSolNetworkOperationResponseSuccess, _GetSolNetworkPackageContentResponseSuccess, _GetSolNetworkPackageDescriptorResponseSuccess, _GetSolNetworkPackageResponseSuccess, _InstantiateSolNetworkInstanceResponseSuccess, _ListSolFunctionInstancesResponseSuccess, _ListSolFunctionPackagesResponseSuccess, _ListSolNetworkInstancesResponseSuccess, _ListSolNetworkOperationsResponseSuccess, _ListSolNetworkPackagesResponseSuccess, _ListTagsForResourceResponseSuccess, _PutSolFunctionPackageContentResponseSuccess, _PutSolNetworkPackageContentResponseSuccess, _TagResourceResponseSuccess, _TerminateSolNetworkInstanceResponseSuccess, _UntagResourceResponseSuccess, _UpdateSolFunctionPackageResponseSuccess, _UpdateSolNetworkInstanceResponseSuccess, _UpdateSolNetworkPackageResponseSuccess, _ValidateSolFunctionPackageContentResponseSuccess, _ValidateSolNetworkPackageContentResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_sol_network_operation(params = {}) ⇒ Struct
Cancels a network operation.
-
#create_sol_function_package(params = {}) ⇒ Types::CreateSolFunctionPackageOutput
Creates a function package.
-
#create_sol_network_instance(params = {}) ⇒ Types::CreateSolNetworkInstanceOutput
Creates a network instance.
-
#create_sol_network_package(params = {}) ⇒ Types::CreateSolNetworkPackageOutput
Creates a network package.
-
#delete_sol_function_package(params = {}) ⇒ Struct
Deletes a function package.
-
#delete_sol_network_instance(params = {}) ⇒ Struct
Deletes a network instance.
-
#delete_sol_network_package(params = {}) ⇒ Struct
Deletes network package.
-
#get_sol_function_instance(params = {}) ⇒ Types::GetSolFunctionInstanceOutput
Gets the details of a network function instance, including the instantiation state and metadata from the function package descriptor in the network function package.
-
#get_sol_function_package(params = {}) ⇒ Types::GetSolFunctionPackageOutput
Gets the details of an individual function package, such as the operational state and whether the package is in use.
-
#get_sol_function_package_content(params = {}) ⇒ Types::GetSolFunctionPackageContentOutput
Gets the contents of a function package.
-
#get_sol_function_package_descriptor(params = {}) ⇒ Types::GetSolFunctionPackageDescriptorOutput
Gets a function package descriptor in a function package.
-
#get_sol_network_instance(params = {}) ⇒ Types::GetSolNetworkInstanceOutput
Gets the details of the network instance.
-
#get_sol_network_operation(params = {}) ⇒ Types::GetSolNetworkOperationOutput
Gets the details of a network operation, including the tasks involved in the network operation and the status of the tasks.
-
#get_sol_network_package(params = {}) ⇒ Types::GetSolNetworkPackageOutput
Gets the details of a network package.
-
#get_sol_network_package_content(params = {}) ⇒ Types::GetSolNetworkPackageContentOutput
Gets the contents of a network package.
-
#get_sol_network_package_descriptor(params = {}) ⇒ Types::GetSolNetworkPackageDescriptorOutput
Gets the content of the network service descriptor.
-
#instantiate_sol_network_instance(params = {}) ⇒ Types::InstantiateSolNetworkInstanceOutput
Instantiates a network instance.
-
#list_sol_function_instances(params = {}) ⇒ Types::ListSolFunctionInstancesOutput
Lists network function instances.
-
#list_sol_function_packages(params = {}) ⇒ Types::ListSolFunctionPackagesOutput
Lists information about function packages.
-
#list_sol_network_instances(params = {}) ⇒ Types::ListSolNetworkInstancesOutput
Lists your network instances.
-
#list_sol_network_operations(params = {}) ⇒ Types::ListSolNetworkOperationsOutput
Lists details for a network operation, including when the operation started and the status of the operation.
-
#list_sol_network_packages(params = {}) ⇒ Types::ListSolNetworkPackagesOutput
Lists network packages.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists tags for AWS TNB resources.
-
#put_sol_function_package_content(params = {}) ⇒ Types::PutSolFunctionPackageContentOutput
Uploads the contents of a function package.
-
#put_sol_network_package_content(params = {}) ⇒ Types::PutSolNetworkPackageContentOutput
Uploads the contents of a network package.
-
#tag_resource(params = {}) ⇒ Struct
Tags an AWS TNB resource.
-
#terminate_sol_network_instance(params = {}) ⇒ Types::TerminateSolNetworkInstanceOutput
Terminates a network instance.
-
#untag_resource(params = {}) ⇒ Struct
Untags an AWS TNB resource.
-
#update_sol_function_package(params = {}) ⇒ Types::UpdateSolFunctionPackageOutput
Updates the operational state of function package.
-
#update_sol_network_instance(params = {}) ⇒ Types::UpdateSolNetworkInstanceOutput
Update a network instance.
-
#update_sol_network_package(params = {}) ⇒ Types::UpdateSolNetworkPackageOutput
Updates the operational state of a network package.
-
#validate_sol_function_package_content(params = {}) ⇒ Types::ValidateSolFunctionPackageContentOutput
Validates function package content.
-
#validate_sol_network_package_content(params = {}) ⇒ Types::ValidateSolNetworkPackageContentOutput
Validates network package content.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-tnb/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2153 2154 2155 |
# File 'lib/aws-sdk-tnb/client.rb', line 2153 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2156 2157 2158 |
# File 'lib/aws-sdk-tnb/client.rb', line 2156 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 |
# File 'lib/aws-sdk-tnb/client.rb', line 2126 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Tnb') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-tnb' context[:gem_version] = '1.46.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_sol_network_operation(params = {}) ⇒ Struct
Cancels a network operation.
A network operation is any operation that is done to your network, such as network instance instantiation or termination.
82 |
# File 'sig/client.rbs', line 82
def cancel_sol_network_operation: (
|
#create_sol_function_package(params = {}) ⇒ Types::CreateSolFunctionPackageOutput
Creates a function package.
A function package is a .zip file in CSAR (Cloud Service Archive) format that contains a network function (an ETSI standard telecommunication application) and function package descriptor that uses the TOSCA standard to describe how the network functions should run on your network. For more information, see Function packages in the Amazon Web Services Telco Network Builder User Guide.
Creating a function package is the first step for creating a network in AWS TNB. This request creates an empty container with an ID. The next step is to upload the actual CSAR zip file into that empty container. To upload function package content, see PutSolFunctionPackageContent.
97 |
# File 'sig/client.rbs', line 97
def create_sol_function_package: (
|
#create_sol_network_instance(params = {}) ⇒ Types::CreateSolNetworkInstanceOutput
Creates a network instance.
A network instance is a single network created in Amazon Web Services TNB that can be deployed and on which life-cycle operations (like terminate, update, and delete) can be performed. Creating a network instance is the third step after creating a network package. For more information about network instances, Network instances in the Amazon Web Services Telco Network Builder User Guide.
Once you create a network instance, you can instantiate it. To instantiate a network, see InstantiateSolNetworkInstance.
111 |
# File 'sig/client.rbs', line 111
def create_sol_network_instance: (
|
#create_sol_network_package(params = {}) ⇒ Types::CreateSolNetworkPackageOutput
Creates a network package.
A network package is a .zip file in CSAR (Cloud Service Archive) format defines the function packages you want to deploy and the Amazon Web Services infrastructure you want to deploy them on. For more information, see Network instances in the Amazon Web Services Telco Network Builder User Guide.
A network package consists of a network service descriptor (NSD) file (required) and any additional files (optional), such as scripts specific to your needs. For example, if you have multiple function packages in your network package, you can use the NSD to define which network functions should run in certain VPCs, subnets, or EKS clusters.
This request creates an empty network package container with an ID. Once you create a network package, you can upload the network package content using PutSolNetworkPackageContent.
129 |
# File 'sig/client.rbs', line 129
def create_sol_network_package: (
|
#delete_sol_function_package(params = {}) ⇒ Struct
Deletes a function package.
A function package is a .zip file in CSAR (Cloud Service Archive) format that contains a network function (an ETSI standard telecommunication application) and function package descriptor that uses the TOSCA standard to describe how the network functions should run on your network.
To delete a function package, the package must be in a disabled state. To disable a function package, see UpdateSolFunctionPackage.
135 |
# File 'sig/client.rbs', line 135
def delete_sol_function_package: (
|
#delete_sol_network_instance(params = {}) ⇒ Struct
Deletes a network instance.
A network instance is a single network created in Amazon Web Services TNB that can be deployed and on which life-cycle operations (like terminate, update, and delete) can be performed.
To delete a network instance, the instance must be in a stopped or terminated state. To terminate a network instance, see TerminateSolNetworkInstance.
141 |
# File 'sig/client.rbs', line 141
def delete_sol_network_instance: (
|
#delete_sol_network_package(params = {}) ⇒ Struct
Deletes network package.
A network package is a .zip file in CSAR (Cloud Service Archive) format defines the function packages you want to deploy and the Amazon Web Services infrastructure you want to deploy them on.
To delete a network package, the package must be in a disable state. To disable a network package, see UpdateSolNetworkPackage.
147 |
# File 'sig/client.rbs', line 147
def delete_sol_network_package: (
|
#get_sol_function_instance(params = {}) ⇒ Types::GetSolFunctionInstanceOutput
Gets the details of a network function instance, including the instantiation state and metadata from the function package descriptor in the network function package.
A network function instance is a function in a function package .
168 |
# File 'sig/client.rbs', line 168
def get_sol_function_instance: (
|
#get_sol_function_package(params = {}) ⇒ Types::GetSolFunctionPackageOutput
Gets the details of an individual function package, such as the operational state and whether the package is in use.
A function package is a .zip file in CSAR (Cloud Service Archive) format that contains a network function (an ETSI standard telecommunication application) and function package descriptor that uses the TOSCA standard to describe how the network functions should run on your network..
188 |
# File 'sig/client.rbs', line 188
def get_sol_function_package: (
|
#get_sol_function_package_content(params = {}) ⇒ Types::GetSolFunctionPackageContentOutput
Gets the contents of a function package.
A function package is a .zip file in CSAR (Cloud Service Archive) format that contains a network function (an ETSI standard telecommunication application) and function package descriptor that uses the TOSCA standard to describe how the network functions should run on your network.
199 |
# File 'sig/client.rbs', line 199
def get_sol_function_package_content: (
|
#get_sol_function_package_descriptor(params = {}) ⇒ Types::GetSolFunctionPackageDescriptorOutput
Gets a function package descriptor in a function package.
A function package descriptor is a .yaml file in a function package that uses the TOSCA standard to describe how the network function in the function package should run on your network.
A function package is a .zip file in CSAR (Cloud Service Archive) format that contains a network function (an ETSI standard telecommunication application) and function package descriptor that uses the TOSCA standard to describe how the network functions should run on your network.
211 |
# File 'sig/client.rbs', line 211
def get_sol_function_package_descriptor: (
|
#get_sol_network_instance(params = {}) ⇒ Types::GetSolNetworkInstanceOutput
Gets the details of the network instance.
A network instance is a single network created in Amazon Web Services TNB that can be deployed and on which life-cycle operations (like terminate, update, and delete) can be performed.
231 |
# File 'sig/client.rbs', line 231
def get_sol_network_instance: (
|
#get_sol_network_operation(params = {}) ⇒ Types::GetSolNetworkOperationOutput
Gets the details of a network operation, including the tasks involved in the network operation and the status of the tasks.
A network operation is any operation that is done to your network, such as network instance instantiation or termination.
249 |
# File 'sig/client.rbs', line 249
def get_sol_network_operation: (
|
#get_sol_network_package(params = {}) ⇒ Types::GetSolNetworkPackageOutput
Gets the details of a network package.
A network package is a .zip file in CSAR (Cloud Service Archive) format defines the function packages you want to deploy and the Amazon Web Services infrastructure you want to deploy them on.
269 |
# File 'sig/client.rbs', line 269
def get_sol_network_package: (
|
#get_sol_network_package_content(params = {}) ⇒ Types::GetSolNetworkPackageContentOutput
Gets the contents of a network package.
A network package is a .zip file in CSAR (Cloud Service Archive) format defines the function packages you want to deploy and the Amazon Web Services infrastructure you want to deploy them on.
280 |
# File 'sig/client.rbs', line 280
def get_sol_network_package_content: (
|
#get_sol_network_package_descriptor(params = {}) ⇒ Types::GetSolNetworkPackageDescriptorOutput
Gets the content of the network service descriptor.
A network service descriptor is a .yaml file in a network package that uses the TOSCA standard to describe the network functions you want to deploy and the Amazon Web Services infrastructure you want to deploy the network functions on.
292 |
# File 'sig/client.rbs', line 292
def get_sol_network_package_descriptor: (
|
#instantiate_sol_network_instance(params = {}) ⇒ Types::InstantiateSolNetworkInstanceOutput
Instantiates a network instance.
A network instance is a single network created in Amazon Web Services TNB that can be deployed and on which life-cycle operations (like terminate, update, and delete) can be performed.
Before you can instantiate a network instance, you have to create a network instance. For more information, see CreateSolNetworkInstance.
303 |
# File 'sig/client.rbs', line 303
def instantiate_sol_network_instance: (
|
#list_sol_function_instances(params = {}) ⇒ Types::ListSolFunctionInstancesOutput
Lists network function instances.
A network function instance is a function in a function package .
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
318 |
# File 'sig/client.rbs', line 318
def list_sol_function_instances: (
|
#list_sol_function_packages(params = {}) ⇒ Types::ListSolFunctionPackagesOutput
Lists information about function packages.
A function package is a .zip file in CSAR (Cloud Service Archive) format that contains a network function (an ETSI standard telecommunication application) and function package descriptor that uses the TOSCA standard to describe how the network functions should run on your network.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
330 |
# File 'sig/client.rbs', line 330
def list_sol_function_packages: (
|
#list_sol_network_instances(params = {}) ⇒ Types::ListSolNetworkInstancesOutput
Lists your network instances.
A network instance is a single network created in Amazon Web Services TNB that can be deployed and on which life-cycle operations (like terminate, update, and delete) can be performed.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
342 |
# File 'sig/client.rbs', line 342
def list_sol_network_instances: (
|
#list_sol_network_operations(params = {}) ⇒ Types::ListSolNetworkOperationsOutput
Lists details for a network operation, including when the operation started and the status of the operation.
A network operation is any operation that is done to your network, such as network instance instantiation or termination.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
354 |
# File 'sig/client.rbs', line 354
def list_sol_network_operations: (
|
#list_sol_network_packages(params = {}) ⇒ Types::ListSolNetworkPackagesOutput
Lists network packages.
A network package is a .zip file in CSAR (Cloud Service Archive) format defines the function packages you want to deploy and the Amazon Web Services infrastructure you want to deploy them on.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
367 |
# File 'sig/client.rbs', line 367
def list_sol_network_packages: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists tags for AWS TNB resources.
378 |
# File 'sig/client.rbs', line 378
def list_tags_for_resource: (
|
#put_sol_function_package_content(params = {}) ⇒ Types::PutSolFunctionPackageContentOutput
Uploads the contents of a function package.
A function package is a .zip file in CSAR (Cloud Service Archive) format that contains a network function (an ETSI standard telecommunication application) and function package descriptor that uses the TOSCA standard to describe how the network functions should run on your network.
393 |
# File 'sig/client.rbs', line 393
def put_sol_function_package_content: (
|
#put_sol_network_package_content(params = {}) ⇒ Types::PutSolNetworkPackageContentOutput
Uploads the contents of a network package.
A network package is a .zip file in CSAR (Cloud Service Archive) format defines the function packages you want to deploy and the Amazon Web Services infrastructure you want to deploy them on.
411 |
# File 'sig/client.rbs', line 411
def put_sol_network_package_content: (
|
#tag_resource(params = {}) ⇒ Struct
Tags an AWS TNB resource.
A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key and an optional value. You can use tags to search and filter your resources or track your Amazon Web Services costs.
422 |
# File 'sig/client.rbs', line 422
def tag_resource: (
|
#terminate_sol_network_instance(params = {}) ⇒ Types::TerminateSolNetworkInstanceOutput
Terminates a network instance.
A network instance is a single network created in Amazon Web Services TNB that can be deployed and on which life-cycle operations (like terminate, update, and delete) can be performed.
You must terminate a network instance before you can delete it.
434 |
# File 'sig/client.rbs', line 434
def terminate_sol_network_instance: (
|
#untag_resource(params = {}) ⇒ Struct
Untags an AWS TNB resource.
A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key and an optional value. You can use tags to search and filter your resources or track your Amazon Web Services costs.
444 |
# File 'sig/client.rbs', line 444
def untag_resource: (
|
#update_sol_function_package(params = {}) ⇒ Types::UpdateSolFunctionPackageOutput
Updates the operational state of function package.
A function package is a .zip file in CSAR (Cloud Service Archive) format that contains a network function (an ETSI standard telecommunication application) and function package descriptor that uses the TOSCA standard to describe how the network functions should run on your network.
455 |
# File 'sig/client.rbs', line 455
def update_sol_function_package: (
|
#update_sol_network_instance(params = {}) ⇒ Types::UpdateSolNetworkInstanceOutput
Update a network instance.
A network instance is a single network created in Amazon Web Services TNB that can be deployed and on which life-cycle operations (like terminate, update, and delete) can be performed.
Choose the updateType parameter to target the necessary update of the network instance.
467 |
# File 'sig/client.rbs', line 467
def update_sol_network_instance: (
|
#update_sol_network_package(params = {}) ⇒ Types::UpdateSolNetworkPackageOutput
Updates the operational state of a network package.
A network package is a .zip file in CSAR (Cloud Service Archive) format defines the function packages you want to deploy and the Amazon Web Services infrastructure you want to deploy them on.
A network service descriptor is a .yaml file in a network package that uses the TOSCA standard to describe the network functions you want to deploy and the Amazon Web Services infrastructure you want to deploy the network functions on.
489 |
# File 'sig/client.rbs', line 489
def update_sol_network_package: (
|
#validate_sol_function_package_content(params = {}) ⇒ Types::ValidateSolFunctionPackageContentOutput
Validates function package content. This can be used as a dry run before uploading function package content with PutSolFunctionPackageContent.
A function package is a .zip file in CSAR (Cloud Service Archive) format that contains a network function (an ETSI standard telecommunication application) and function package descriptor that uses the TOSCA standard to describe how the network functions should run on your network.
505 |
# File 'sig/client.rbs', line 505
def validate_sol_function_package_content: (
|
#validate_sol_network_package_content(params = {}) ⇒ Types::ValidateSolNetworkPackageContentOutput
Validates network package content. This can be used as a dry run before uploading network package content with PutSolNetworkPackageContent.
A network package is a .zip file in CSAR (Cloud Service Archive) format defines the function packages you want to deploy and the Amazon Web Services infrastructure you want to deploy them on.
523 |
# File 'sig/client.rbs', line 523
def validate_sol_network_package_content: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2146 2147 2148 |
# File 'lib/aws-sdk-tnb/client.rb', line 2146 def waiter_names [] end |