Class: Aws::Tnb::Types::GetSolFunctionPackageOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-tnb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:tags]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

Function package ARN.

Returns:



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
# File 'lib/aws-sdk-tnb/types.rb', line 563

class GetSolFunctionPackageOutput < Struct.new(
  :arn,
  :id,
  :metadata,
  :onboarding_state,
  :operational_state,
  :tags,
  :usage_state,
  :vnf_product_name,
  :vnf_provider,
  :vnfd_id,
  :vnfd_version)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#idString

Function package ID.

Returns:



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
# File 'lib/aws-sdk-tnb/types.rb', line 563

class GetSolFunctionPackageOutput < Struct.new(
  :arn,
  :id,
  :metadata,
  :onboarding_state,
  :operational_state,
  :tags,
  :usage_state,
  :vnf_product_name,
  :vnf_provider,
  :vnfd_id,
  :vnfd_version)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#metadataTypes::GetSolFunctionPackageMetadata

Metadata related to the function package.

A function package is a .zip file in CSAR (Cloud Service Archive) format that contains a network function (an ETSI standard telecommunication application) and function package descriptor that uses the TOSCA standard to describe how the network functions should run on your network.

Returns:



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
# File 'lib/aws-sdk-tnb/types.rb', line 563

class GetSolFunctionPackageOutput < Struct.new(
  :arn,
  :id,
  :metadata,
  :onboarding_state,
  :operational_state,
  :tags,
  :usage_state,
  :vnf_product_name,
  :vnf_provider,
  :vnfd_id,
  :vnfd_version)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#onboarding_stateString

Function package onboarding state.

Returns:



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
# File 'lib/aws-sdk-tnb/types.rb', line 563

class GetSolFunctionPackageOutput < Struct.new(
  :arn,
  :id,
  :metadata,
  :onboarding_state,
  :operational_state,
  :tags,
  :usage_state,
  :vnf_product_name,
  :vnf_provider,
  :vnfd_id,
  :vnfd_version)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#operational_stateString

Function package operational state.

Returns:



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
# File 'lib/aws-sdk-tnb/types.rb', line 563

class GetSolFunctionPackageOutput < Struct.new(
  :arn,
  :id,
  :metadata,
  :onboarding_state,
  :operational_state,
  :tags,
  :usage_state,
  :vnf_product_name,
  :vnf_provider,
  :vnfd_id,
  :vnfd_version)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#tagsHash<String,String>

A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key and an optional value. You can use tags to search and filter your resources or track your Amazon Web Services costs.

Returns:



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
# File 'lib/aws-sdk-tnb/types.rb', line 563

class GetSolFunctionPackageOutput < Struct.new(
  :arn,
  :id,
  :metadata,
  :onboarding_state,
  :operational_state,
  :tags,
  :usage_state,
  :vnf_product_name,
  :vnf_provider,
  :vnfd_id,
  :vnfd_version)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#usage_stateString

Function package usage state.

Returns:



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
# File 'lib/aws-sdk-tnb/types.rb', line 563

class GetSolFunctionPackageOutput < Struct.new(
  :arn,
  :id,
  :metadata,
  :onboarding_state,
  :operational_state,
  :tags,
  :usage_state,
  :vnf_product_name,
  :vnf_provider,
  :vnfd_id,
  :vnfd_version)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#vnf_product_nameString

Network function product name.

Returns:



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
# File 'lib/aws-sdk-tnb/types.rb', line 563

class GetSolFunctionPackageOutput < Struct.new(
  :arn,
  :id,
  :metadata,
  :onboarding_state,
  :operational_state,
  :tags,
  :usage_state,
  :vnf_product_name,
  :vnf_provider,
  :vnfd_id,
  :vnfd_version)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#vnf_providerString

Network function provider.

Returns:



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
# File 'lib/aws-sdk-tnb/types.rb', line 563

class GetSolFunctionPackageOutput < Struct.new(
  :arn,
  :id,
  :metadata,
  :onboarding_state,
  :operational_state,
  :tags,
  :usage_state,
  :vnf_product_name,
  :vnf_provider,
  :vnfd_id,
  :vnfd_version)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#vnfd_idString

Function package descriptor ID.

Returns:



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
# File 'lib/aws-sdk-tnb/types.rb', line 563

class GetSolFunctionPackageOutput < Struct.new(
  :arn,
  :id,
  :metadata,
  :onboarding_state,
  :operational_state,
  :tags,
  :usage_state,
  :vnf_product_name,
  :vnf_provider,
  :vnfd_id,
  :vnfd_version)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#vnfd_versionString

Function package descriptor version.

Returns:



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
# File 'lib/aws-sdk-tnb/types.rb', line 563

class GetSolFunctionPackageOutput < Struct.new(
  :arn,
  :id,
  :metadata,
  :onboarding_state,
  :operational_state,
  :tags,
  :usage_state,
  :vnf_product_name,
  :vnf_provider,
  :vnfd_id,
  :vnfd_version)
  SENSITIVE = [:tags]
  include Aws::Structure
end